<?php

header('Content-Type: application/json; charset=utf-8');
// See http://www.w3.org/TR/cors/
$allowedOrigins = array(
  'http://localhost',
  'http://localhost:8080',
  'http://dtm',
  'http://gamma.dtele.de'
);
if (($index = array_search($_SERVER['HTTP_ORIGIN'], $allowedOrigins)) !== false) {

  header('Access-Control-Allow-Origin: ' . $allowedOrigins[$index]);
}

define('MEDIA_URL', 'media/');
define('MEDIA_PATH', dirname($_SERVER['SCRIPT_FILENAME']) . '/' . MEDIA_URL);
define('MEDIA_REQUEST_VERSION', 1.0);

define('ERROR_UNKNOWN', 'unknown');
define('ERROR_UNKNOWN_PROTOCOL_VERSION', 'unknownProtocolVersion');
define('ERROR_UNKNOWN_REQUEST_TYPE', 'unknownRequestType');
define('ERROR_AUTHENTICATION_REQUIRED', 'authenticationRequired');
define('ERROR_AUTHENTICATION_FAILED', 'authenticationFailed');

$response = array();

if (isset($_POST['mediaRequest'])) {

  if ($_POST['mediaRequest']['version'] == MEDIA_REQUEST_VERSION) {

    $response = array(
      'version' => MEDIA_REQUEST_VERSION,
      'type' => $_POST['mediaRequest']['type']
    );
    
    if (isset($_POST['mediaRequest']['id'])) {
    
      $response['requestId'] = $_POST['mediaRequest']['id'];
    }
  
    switch ($_POST['mediaRequest']['type']) {
    
      case 'info':
      
        $response['result'] = 'success';
        $response['info'] = array(
          'title' => 'Mikan',
          'allowed' => array('list'),
        );
        break;
        
      case 'list':
      
        $response['result'] = 'success';
        $response['resources'] = array(
          MEDIA_URL . 'image/mandarin.jpg' => array(
            'title' => 'Mandarine',
            'type' => 'image/jpeg',
            'size' => 12497,
            'thumbnail' => MEDIA_URL . 'image/mandarin-thumb.jpg',
          ),
          MEDIA_URL . 'image/shore.jpg' => array(
            'title' => 'Küste',
            'type' => 'image/jpeg',
            'size' => 158084,
            'thumbnail' => MEDIA_URL . 'image/shore-thumb.jpg',
          ),
          MEDIA_URL . 'image/does-not-exist.jpg' => array(
            'title' => '[Nicht existent]',
            'type' => 'image/jpg',
            'thumbnail' => MEDIA_URL . 'image/does-not-exist-thumb.jpg',
          )
        );
        break;
        
      default:
        
        $response['result'] = 'error';
        $response['error'] = array(
          'code' => ERROR_UNKNOWN_REQUEST_TYPE,
          'message' => 'Unknown request type.'
        );
        break;
    }
  } else {
  
    $response['result'] = 'error';
    $response['error'] = array(
      'code' => ERROR_UNKNOWN_PROTOCOL_VERSION,
      'message' => 'Unknown protocol version.'
    );
  }
}

echo json_encode($response);

?>
